KG2ESimilarity
==============

.. currentmodule:: pykeen.nn.sim

.. autoclass:: KG2ESimilarity
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~KG2ESimilarity.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
